@@ -34,4 +34,4 @@ def set_logger_level(logger:logging.Logger,log_level:str):
 
     for level_name,level_value in level_mapping:
             if log_level == level_name:
-                    logger.setLevel(level_name,level_value)
+                    logger.setLevel(level_value)
